from kaistack.metadata import context
from kaistack.clients.openapi_clients.workflow.models import CodegenMetric, CodegenParam, CodegenArtifactMeta
from datetime import datetime

ARTIFACT_TYPE_MODEL = "MODEL"
_MODEL_NAME_PROP_NAME = "Model_Name"
_MODEL_FRAMEWORK_PROP_NAME = "Model_Framework"
_MODEL_VERSION_PROP_NAME = "Model_Version"
_MODEL_FRAMEWORKVERSION_PROP_NAME = "Model_FrameworkVersion"

def log_param(key, value):
    context.ensure_init()
    p = CodegenParam(run_id=context.get_run_id(), pipeline_run_id=context.get_pipeline_run_id(), name=key, value=value)
    context.workflowservice().log_params([p])


def log_params(params):
    context.ensure_init()
    vals = []
    for k, v in params.items():
        vals.append(CodegenParam(run_id=context.get_run_id(),
                                 pipeline_run_id=context.get_pipeline_run_id(),
                                 name=k,
                                 value=v))
    return context.workflowservice().log_params(vals)


def log_metrics(metrics):
    context.ensure_init()
    vals = []
    for k, v in metrics.items():
        vals.append(CodegenParam(run_id=context.get_run_id(),
                                 pipeline_run_id=context.get_pipeline_run_id(),
                                 name=k,
                                 value=v))
    return context.workflowservice().log_metrics(vals)


def log_metric(key, value):
    context.ensure_init()
    m = CodegenMetric(run_id=context.get_run_id(),
                      pipeline_run_id=context.get_pipeline_run_id(),
                      name=key, value=value)
    context.workflowservice().log_metrics([m])


def log_artifact_meta(artifact_path=None, artifact_type=None, properties=None):
    context.ensure_init()
    meta = CodegenArtifactMeta(run_id=context.get_run_id(), path=artifact_path, type=artifact_type,
                               properties=properties)
    context.workflowservice().log_artifact_meta(meta)


def log_model(artifact_path=None, model_name="", version=None, framework="", framework_version="", properties={}):
    '''
    Log an model. This is a simple wrapper around the log_artifact_meta
    '''
    context.ensure_init()
    if version is None:
        version = datetime.utcnow().isoformat(timespec='seconds')
    default_props = {
        _MODEL_NAME_PROP_NAME: model_name,
        _MODEL_VERSION_PROP_NAME: version,
        _MODEL_FRAMEWORK_PROP_NAME: framework,
        _MODEL_FRAMEWORKVERSION_PROP_NAME: framework_version
    }

    properties.update(default_props)
    log_artifact_meta(artifact_path=artifact_path, artifact_type=ARTIFACT_TYPE_MODEL, properties=properties)



import os
import unittest

from kaistack.components.component_store import create_from_template

ARGO_SPEC_FILENAME = os.path.join(os.path.dirname(__file__), 'argo_component.yaml')
ARGO_SPEC_FILENAME_2 = os.path.join(os.path.dirname(__file__), 'argo_component_2.yaml')


class ComponentStoreTest(unittest.TestCase):
    def setUp(self) -> None:
        pass

    def tearDown(self) -> None:
        pass

    def test_create_from_component(self):
        with open(ARGO_SPEC_FILENAME, 'r') as f:
            spec = f.read()
            component = create_from_template(spec)
            self.assertEqual("Git clone", component.name)
            self.assertEqual("Creates a shallow clone of the specified repo branch", component.description)
            self.assertEqual("alpine/git", component.image)

    def test_create_from_component_2(self):
        with open(ARGO_SPEC_FILENAME_2, 'r') as f:
            spec = f.read()
            component = create_from_template(spec)
            self.assertEqual("preprocess", component.name)



import json
import logging
import os
import nbformat
from nbconvert import HTMLExporter

import papermill as pm

PREFIX = "KAISTACK_NOTEBOOK_PARAM"
CLOUDPROVIDER = "KAISTACK_CLOUD_PROVIDER"
OUTPUTSTORAGEURI = "KAISTACK_OUTPUT_STORAGE_URI"
NOTEBOOKJOBNAME = "KAISTACK_NOTEBOOK_JOB_NAME"
PODNAME = "POD_NAME"
logger = logging.getLogger("Notebook Runner")
console_handler = logging.StreamHandler()
logger.addHandler(console_handler)
logger.setLevel(logging.INFO)


def get_value(v: str):
    '''
    The value is passed via environment variables. Support str, boolean and number now
    The rules is string will have double quotes around string. Otherwise will try to parse as boolean
    or number
    '''
    logger.info(v)
    try:
        result = json.loads(v.lower())
    except json.decoder.JSONDecodeError:
        return v
    if type(result) is str:
        return v  # result is in lower case
    else:
        return result


def generate_parameters() -> dict:
    ret = {}
    for k, v in os.environ.items():
        if k.startswith(PREFIX) and len(k) > len(PREFIX) + 1:
            ret[k[len(PREFIX) + 1:]] = get_value(v)
    return ret


def convert_to_html(input_file):
    '''Invoke nbconvert to export html'''
    nb = nbformat.read(input_file, 4)
    html_exporter = HTMLExporter()
    logger.info("Exporting output as html")
    (output, resources) = html_exporter.from_notebook_node(nb)
    with open(input_file + ".html", "w") as f:
        f.write(output)


def main():
    parameters = generate_parameters()
    logger.info("Parameters is {0}".format(parameters))
    INPUT = os.environ["KAISTACK_INPUT_NOTEBOOK"]
    logger.info("INPUT is {0}".format(parameters))
    OUTPUT = os.environ["KAISTACK_OUTPUT_NOTEBOOK"]
    logger.info("OUTPUT is {0}".format(parameters))
    cloudProvider = os.environ[CLOUDPROVIDER]
    outputuri = os.environ[OUTPUTSTORAGEURI]
    jobName = os.environ[NOTEBOOKJOBNAME]
    podName = os.environ[PODNAME]
    logger.info("Cloudprovider is {0}. Output is {1}. JobName is {2}. Run Name is {3}".format(cloudProvider,
                                                                                              outputuri, jobName,
                                                                                              podName))

    pm.execute_notebook(INPUT, OUTPUT, parameters, log_output=True)
    convert_to_html(OUTPUT)



# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kaistack.clients.openapi_clients.workflow.api_client import ApiClient
from kaistack.clients.openapi_clients.workflow.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class WorkflowServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_run(self, body, **kwargs):  # noqa: E501
        """create_run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_run(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CodegenRun body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenCreateRunResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_run_with_http_info(body, **kwargs)  # noqa: E501

    def create_run_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_run_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CodegenRun body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenCreateRunResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_run" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `create_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/runs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenCreateRunResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_models_latest_version(self, **kwargs):  # noqa: E501
        """get_all_models_latest_version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_models_latest_version(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetAllModelsLatestVersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_all_models_latest_version_with_http_info(**kwargs)  # noqa: E501

    def get_all_models_latest_version_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_models_latest_version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_models_latest_version_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetAllModelsLatestVersionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_models_latest_version" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/models', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetAllModelsLatestVersionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_argo_workflow(self, run_id, **kwargs):  # noqa: E501
        """get_argo_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_argo_workflow(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetArgoWorkflowResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_argo_workflow_with_http_info(run_id, **kwargs)  # noqa: E501

    def get_argo_workflow_with_http_info(self, run_id, **kwargs):  # noqa: E501
        """get_argo_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_argo_workflow_with_http_info(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetArgoWorkflowResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_argo_workflow" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `get_argo_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/pipeline/{runId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetArgoWorkflowResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_artifact_with_properties(self, id, **kwargs):  # noqa: E501
        """get_artifact_with_properties  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_artifact_with_properties(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetArtifactWithPropertiesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_artifact_with_properties_with_http_info(id, **kwargs)  # noqa: E501

    def get_artifact_with_properties_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_artifact_with_properties  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_artifact_with_properties_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetArtifactWithPropertiesResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_artifact_with_properties" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_artifact_with_properties`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/artifacts/full/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetArtifactWithPropertiesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_artifacts_with_filter(self, **kwargs):  # noqa: E501
        """get_artifacts_with_filter  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_artifacts_with_filter(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str filter_experiment:
        :param str filter_pipeline_run_id:
        :param str filter_run_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetArtifactsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_artifacts_with_filter_with_http_info(**kwargs)  # noqa: E501

    def get_artifacts_with_filter_with_http_info(self, **kwargs):  # noqa: E501
        """get_artifacts_with_filter  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_artifacts_with_filter_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str filter_experiment:
        :param str filter_pipeline_run_id:
        :param str filter_run_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetArtifactsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'filter_experiment',
            'filter_pipeline_run_id',
            'filter_run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_artifacts_with_filter" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter_experiment' in local_var_params and local_var_params['filter_experiment'] is not None:  # noqa: E501
            query_params.append(('filter.experiment', local_var_params['filter_experiment']))  # noqa: E501
        if 'filter_pipeline_run_id' in local_var_params and local_var_params['filter_pipeline_run_id'] is not None:  # noqa: E501
            query_params.append(('filter.pipelineRunId', local_var_params['filter_pipeline_run_id']))  # noqa: E501
        if 'filter_run_id' in local_var_params and local_var_params['filter_run_id'] is not None:  # noqa: E501
            query_params.append(('filter.runId', local_var_params['filter_run_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/artifacts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetArtifactsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_experiment_pipeline_runs(self, experiment_id, **kwargs):  # noqa: E501
        """get_experiment_pipeline_runs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_experiment_pipeline_runs(experiment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str experiment_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetExperimentRunsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_experiment_pipeline_runs_with_http_info(experiment_id, **kwargs)  # noqa: E501

    def get_experiment_pipeline_runs_with_http_info(self, experiment_id, **kwargs):  # noqa: E501
        """get_experiment_pipeline_runs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_experiment_pipeline_runs_with_http_info(experiment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str experiment_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetExperimentRunsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'experiment_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_experiment_pipeline_runs" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'experiment_id' is set
        if self.api_client.client_side_validation and ('experiment_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['experiment_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `experiment_id` when calling `get_experiment_pipeline_runs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'experiment_id' in local_var_params:
            path_params['experimentId'] = local_var_params['experiment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/experiments/{experimentId}/runs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetExperimentRunsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_metrics(self, **kwargs):  # noqa: E501
        """get_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str filter_experiment:
        :param str filter_pipeline_run_id:
        :param str filter_run_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetMetricsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_metrics_with_http_info(**kwargs)  # noqa: E501

    def get_metrics_with_http_info(self, **kwargs):  # noqa: E501
        """get_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str filter_experiment:
        :param str filter_pipeline_run_id:
        :param str filter_run_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetMetricsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'filter_experiment',
            'filter_pipeline_run_id',
            'filter_run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_metrics" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter_experiment' in local_var_params and local_var_params['filter_experiment'] is not None:  # noqa: E501
            query_params.append(('filter.experiment', local_var_params['filter_experiment']))  # noqa: E501
        if 'filter_pipeline_run_id' in local_var_params and local_var_params['filter_pipeline_run_id'] is not None:  # noqa: E501
            query_params.append(('filter.pipelineRunId', local_var_params['filter_pipeline_run_id']))  # noqa: E501
        if 'filter_run_id' in local_var_params and local_var_params['filter_run_id'] is not None:  # noqa: E501
            query_params.append(('filter.runId', local_var_params['filter_run_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/metrics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetMetricsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model_all_versions(self, name, **kwargs):  # noqa: E501
        """get_model_all_versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_all_versions(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetModelAllVersionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_model_all_versions_with_http_info(name, **kwargs)  # noqa: E501

    def get_model_all_versions_with_http_info(self, name, **kwargs):  # noqa: E501
        """get_model_all_versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_all_versions_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetModelAllVersionsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model_all_versions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `get_model_all_versions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/models/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetModelAllVersionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_params(self, **kwargs):  # noqa: E501
        """get_params  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_params(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str filter_experiment:
        :param str filter_pipeline_run_id:
        :param str filter_run_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetParamsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_params_with_http_info(**kwargs)  # noqa: E501

    def get_params_with_http_info(self, **kwargs):  # noqa: E501
        """get_params  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_params_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str filter_experiment:
        :param str filter_pipeline_run_id:
        :param str filter_run_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetParamsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'filter_experiment',
            'filter_pipeline_run_id',
            'filter_run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_params" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter_experiment' in local_var_params and local_var_params['filter_experiment'] is not None:  # noqa: E501
            query_params.append(('filter.experiment', local_var_params['filter_experiment']))  # noqa: E501
        if 'filter_pipeline_run_id' in local_var_params and local_var_params['filter_pipeline_run_id'] is not None:  # noqa: E501
            query_params.append(('filter.pipelineRunId', local_var_params['filter_pipeline_run_id']))  # noqa: E501
        if 'filter_run_id' in local_var_params and local_var_params['filter_run_id'] is not None:  # noqa: E501
            query_params.append(('filter.runId', local_var_params['filter_run_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/params', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetParamsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pipeline_experiment_name(self, run_id, **kwargs):  # noqa: E501
        """get_pipeline_experiment_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pipeline_experiment_name(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetPipelineExperimentNameResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_pipeline_experiment_name_with_http_info(run_id, **kwargs)  # noqa: E501

    def get_pipeline_experiment_name_with_http_info(self, run_id, **kwargs):  # noqa: E501
        """get_pipeline_experiment_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pipeline_experiment_name_with_http_info(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetPipelineExperimentNameResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pipeline_experiment_name" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `get_pipeline_experiment_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/pipeline/{runId}/experiment', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetPipelineExperimentNameResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pipeline_run_id(self, workflow_name, **kwargs):  # noqa: E501
        """get_pipeline_run_id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pipeline_run_id(workflow_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetPipelineRunIdResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_pipeline_run_id_with_http_info(workflow_name, **kwargs)  # noqa: E501

    def get_pipeline_run_id_with_http_info(self, workflow_name, **kwargs):  # noqa: E501
        """get_pipeline_run_id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pipeline_run_id_with_http_info(workflow_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetPipelineRunIdResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pipeline_run_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_name' is set
        if self.api_client.client_side_validation and ('workflow_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_name` when calling `get_pipeline_run_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_name' in local_var_params:
            path_params['workflowName'] = local_var_params['workflow_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/{workflowName}/run', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetPipelineRunIdResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pipeline_runs(self, pipeline_run_id, **kwargs):  # noqa: E501
        """get_pipeline_runs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pipeline_runs(pipeline_run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str pipeline_run_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetPipelineRunsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_pipeline_runs_with_http_info(pipeline_run_id, **kwargs)  # noqa: E501

    def get_pipeline_runs_with_http_info(self, pipeline_run_id, **kwargs):  # noqa: E501
        """get_pipeline_runs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pipeline_runs_with_http_info(pipeline_run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str pipeline_run_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetPipelineRunsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'pipeline_run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pipeline_runs" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'pipeline_run_id' is set
        if self.api_client.client_side_validation and ('pipeline_run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['pipeline_run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_run_id` when calling `get_pipeline_runs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'pipeline_run_id' in local_var_params:
            path_params['pipelineRunId'] = local_var_params['pipeline_run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/pipeline/{pipelineRunId}/runs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetPipelineRunsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_run(self, id, **kwargs):  # noqa: E501
        """get_run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_run(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetRunResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_run_with_http_info(id, **kwargs)  # noqa: E501

    def get_run_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_run_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetRunResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_run" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/runs/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetRunResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_run_by_name(self, name, **kwargs):  # noqa: E501
        """get_run_by_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_run_by_name(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetRunByNameResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_run_by_name_with_http_info(name, **kwargs)  # noqa: E501

    def get_run_by_name_with_http_info(self, name, **kwargs):  # noqa: E501
        """get_run_by_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_run_by_name_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetRunByNameResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_run_by_name" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `get_run_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/runs/name/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetRunByNameResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def log_artifact_meta(self, body, **kwargs):  # noqa: E501
        """log_artifact_meta  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.log_artifact_meta(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CodegenArtifactMeta body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenLogArtifactMetaResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.log_artifact_meta_with_http_info(body, **kwargs)  # noqa: E501

    def log_artifact_meta_with_http_info(self, body, **kwargs):  # noqa: E501
        """log_artifact_meta  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.log_artifact_meta_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CodegenArtifactMeta body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenLogArtifactMetaResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method log_artifact_meta" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `log_artifact_meta`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/artifacts/meta', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenLogArtifactMetaResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def log_metrics(self, body, **kwargs):  # noqa: E501
        """log_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.log_metrics(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str body: grpc-gateway does not support repeated field in body. Pass a json string instead (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenLogMetricsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.log_metrics_with_http_info(body, **kwargs)  # noqa: E501

    def log_metrics_with_http_info(self, body, **kwargs):  # noqa: E501
        """log_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.log_metrics_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str body: grpc-gateway does not support repeated field in body. Pass a json string instead (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenLogMetricsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method log_metrics" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `log_metrics`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/metrics', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenLogMetricsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def log_params(self, body, **kwargs):  # noqa: E501
        """log_params  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.log_params(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str body: grpc-gateway does not support repeated field in body. Pass a json string instead (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenLogParamsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.log_params_with_http_info(body, **kwargs)  # noqa: E501

    def log_params_with_http_info(self, body, **kwargs):  # noqa: E501
        """log_params  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.log_params_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str body: grpc-gateway does not support repeated field in body. Pass a json string instead (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenLogParamsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method log_params" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `log_params`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/params', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenLogParamsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resubmit_workflow(self, namespace, name, **kwargs):  # noqa: E501
        """resubmit_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resubmit_workflow(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenWorkflowActionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.resubmit_workflow_with_http_info(namespace, name, **kwargs)  # noqa: E501

    def resubmit_workflow_with_http_info(self, namespace, name, **kwargs):  # noqa: E501
        """resubmit_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resubmit_workflow_with_http_info(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenWorkflowActionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resubmit_workflow" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `resubmit_workflow`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `resubmit_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/{namespace}/{name}/resubmit', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenWorkflowActionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_workflow(self, namespace, name, **kwargs):  # noqa: E501
        """resume_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_workflow(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenWorkflowActionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.resume_workflow_with_http_info(namespace, name, **kwargs)  # noqa: E501

    def resume_workflow_with_http_info(self, namespace, name, **kwargs):  # noqa: E501
        """resume_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_workflow_with_http_info(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenWorkflowActionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_workflow" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `resume_workflow`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `resume_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/{namespace}/{name}/resume', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenWorkflowActionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retry_workflow(self, namespace, name, **kwargs):  # noqa: E501
        """retry_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retry_workflow(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenWorkflowActionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.retry_workflow_with_http_info(namespace, name, **kwargs)  # noqa: E501

    def retry_workflow_with_http_info(self, namespace, name, **kwargs):  # noqa: E501
        """retry_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retry_workflow_with_http_info(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenWorkflowActionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retry_workflow" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `retry_workflow`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `retry_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/{namespace}/{name}/retry', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenWorkflowActionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def suspend_workflow(self, namespace, name, **kwargs):  # noqa: E501
        """suspend_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.suspend_workflow(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenWorkflowActionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.suspend_workflow_with_http_info(namespace, name, **kwargs)  # noqa: E501

    def suspend_workflow_with_http_info(self, namespace, name, **kwargs):  # noqa: E501
        """suspend_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.suspend_workflow_with_http_info(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenWorkflowActionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method suspend_workflow" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `suspend_workflow`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `suspend_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/{namespace}/{name}/suspend', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenWorkflowActionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def terminate_workflow(self, namespace, name, **kwargs):  # noqa: E501
        """terminate_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.terminate_workflow(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenWorkflowActionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.terminate_workflow_with_http_info(namespace, name, **kwargs)  # noqa: E501

    def terminate_workflow_with_http_info(self, namespace, name, **kwargs):  # noqa: E501
        """terminate_workflow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.terminate_workflow_with_http_info(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenWorkflowActionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method terminate_workflow" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `terminate_workflow`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `terminate_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow/{namespace}/{name}/terminate', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenWorkflowActionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import kaistack.clients.openapi_clients.workflow
from kaistack.clients.openapi_clients.workflow.models.codegen_metric import CodegenMetric  # noqa: E501
from kaistack.clients.openapi_clients.workflow.rest import ApiException

class TestCodegenMetric(unittest.TestCase):
    """CodegenMetric unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CodegenMetric
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kaistack.clients.openapi_clients.workflow.models.codegen_metric.CodegenMetric()  # noqa: E501
        if include_optional :
            return CodegenMetric(
                run_id = '0', 
                name = '0', 
                value = 1.337, 
                create_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else :
            return CodegenMetric(
        )

    def testCodegenMetric(self):
        """Test CodegenMetric"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    clusterapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import kaistack.clients.openapi_clients.cluster
from kaistack.clients.openapi_clients.cluster.models.codegen_get_nodes_response import CodegenGetNodesResponse  # noqa: E501
from kaistack.clients.openapi_clients.cluster.rest import ApiException

class TestCodegenGetNodesResponse(unittest.TestCase):
    """CodegenGetNodesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CodegenGetNodesResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kaistack.clients.openapi_clients.cluster.models.codegen_get_nodes_response.CodegenGetNodesResponse()  # noqa: E501
        if include_optional :
            return CodegenGetNodesResponse(
                nodes = [
                    kaistack.clients.openapi_clients.cluster.models.codegen_node.codegenNode(
                        node_name = '0', 
                        status = '0', 
                        resources = {
                            'key' : '0'
                            }, 
                        labels = {
                            'key' : '0'
                            }, 
                        annotations = {
                            'key' : '0'
                            }, )
                    ]
            )
        else :
            return CodegenGetNodesResponse(
        )

    def testCodegenGetNodesResponse(self):
        """Test CodegenGetNodesResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kaistack.clients.openapi_clients.workflow.configuration import Configuration


class CodegenPiplineRunDetail(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'namespace': 'str',
        'pipeline_id': 'str',
        'experiment_id': 'str',
        'recurring_job_id': 'str',
        'status': 'str',
        'created_at': 'datetime',
        'scheduledd_at': 'datetime',
        'finished_at': 'datetime',
        'pipeline_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'namespace': 'namespace',
        'pipeline_id': 'pipelineId',
        'experiment_id': 'experimentId',
        'recurring_job_id': 'recurringJobId',
        'status': 'status',
        'created_at': 'createdAt',
        'scheduledd_at': 'scheduleddAt',
        'finished_at': 'finishedAt',
        'pipeline_name': 'pipelineName'
    }

    def __init__(self, id=None, name=None, namespace=None, pipeline_id=None, experiment_id=None, recurring_job_id=None, status=None, created_at=None, scheduledd_at=None, finished_at=None, pipeline_name=None, local_vars_configuration=None):  # noqa: E501
        """CodegenPiplineRunDetail - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._namespace = None
        self._pipeline_id = None
        self._experiment_id = None
        self._recurring_job_id = None
        self._status = None
        self._created_at = None
        self._scheduledd_at = None
        self._finished_at = None
        self._pipeline_name = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if namespace is not None:
            self.namespace = namespace
        if pipeline_id is not None:
            self.pipeline_id = pipeline_id
        if experiment_id is not None:
            self.experiment_id = experiment_id
        if recurring_job_id is not None:
            self.recurring_job_id = recurring_job_id
        if status is not None:
            self.status = status
        if created_at is not None:
            self.created_at = created_at
        if scheduledd_at is not None:
            self.scheduledd_at = scheduledd_at
        if finished_at is not None:
            self.finished_at = finished_at
        if pipeline_name is not None:
            self.pipeline_name = pipeline_name

    @property
    def id(self):
        """Gets the id of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The id of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CodegenPiplineRunDetail.


        :param id: The id of this CodegenPiplineRunDetail.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The name of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CodegenPiplineRunDetail.


        :param name: The name of this CodegenPiplineRunDetail.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def namespace(self):
        """Gets the namespace of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The namespace of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this CodegenPiplineRunDetail.


        :param namespace: The namespace of this CodegenPiplineRunDetail.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def pipeline_id(self):
        """Gets the pipeline_id of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The pipeline_id of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_id

    @pipeline_id.setter
    def pipeline_id(self, pipeline_id):
        """Sets the pipeline_id of this CodegenPiplineRunDetail.


        :param pipeline_id: The pipeline_id of this CodegenPiplineRunDetail.  # noqa: E501
        :type: str
        """

        self._pipeline_id = pipeline_id

    @property
    def experiment_id(self):
        """Gets the experiment_id of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The experiment_id of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._experiment_id

    @experiment_id.setter
    def experiment_id(self, experiment_id):
        """Sets the experiment_id of this CodegenPiplineRunDetail.


        :param experiment_id: The experiment_id of this CodegenPiplineRunDetail.  # noqa: E501
        :type: str
        """

        self._experiment_id = experiment_id

    @property
    def recurring_job_id(self):
        """Gets the recurring_job_id of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The recurring_job_id of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._recurring_job_id

    @recurring_job_id.setter
    def recurring_job_id(self, recurring_job_id):
        """Sets the recurring_job_id of this CodegenPiplineRunDetail.


        :param recurring_job_id: The recurring_job_id of this CodegenPiplineRunDetail.  # noqa: E501
        :type: str
        """

        self._recurring_job_id = recurring_job_id

    @property
    def status(self):
        """Gets the status of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The status of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CodegenPiplineRunDetail.


        :param status: The status of this CodegenPiplineRunDetail.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def created_at(self):
        """Gets the created_at of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The created_at of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CodegenPiplineRunDetail.


        :param created_at: The created_at of this CodegenPiplineRunDetail.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def scheduledd_at(self):
        """Gets the scheduledd_at of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The scheduledd_at of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._scheduledd_at

    @scheduledd_at.setter
    def scheduledd_at(self, scheduledd_at):
        """Sets the scheduledd_at of this CodegenPiplineRunDetail.


        :param scheduledd_at: The scheduledd_at of this CodegenPiplineRunDetail.  # noqa: E501
        :type: datetime
        """

        self._scheduledd_at = scheduledd_at

    @property
    def finished_at(self):
        """Gets the finished_at of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The finished_at of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """Sets the finished_at of this CodegenPiplineRunDetail.


        :param finished_at: The finished_at of this CodegenPiplineRunDetail.  # noqa: E501
        :type: datetime
        """

        self._finished_at = finished_at

    @property
    def pipeline_name(self):
        """Gets the pipeline_name of this CodegenPiplineRunDetail.  # noqa: E501


        :return: The pipeline_name of this CodegenPiplineRunDetail.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_name

    @pipeline_name.setter
    def pipeline_name(self, pipeline_name):
        """Sets the pipeline_name of this CodegenPiplineRunDetail.


        :param pipeline_name: The pipeline_name of this CodegenPiplineRunDetail.  # noqa: E501
        :type: str
        """

        self._pipeline_name = pipeline_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodegenPiplineRunDetail):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodegenPiplineRunDetail):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    pipelinecomponentapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import kaistack.clients.openapi_clients.pipelinecomponents
from kaistack.clients.openapi_clients.pipelinecomponents.api.pipeline_component_service_api import PipelineComponentServiceApi  # noqa: E501
from kaistack.clients.openapi_clients.pipelinecomponents.rest import ApiException


class TestPipelineComponentServiceApi(unittest.TestCase):
    """PipelineComponentServiceApi unit test stubs"""

    def setUp(self):
        self.api = kaistack.clients.openapi_clients.pipelinecomponents.api.pipeline_component_service_api.PipelineComponentServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_component(self):
        """Test case for create_component

        """
        pass

    def test_delete_component(self):
        """Test case for delete_component

        """
        pass

    def test_get_component(self):
        """Test case for get_component

        """
        pass

    def test_get_component_by_name(self):
        """Test case for get_component_by_name

        """
        pass

    def test_list_component_versions(self):
        """Test case for list_component_versions

        """
        pass

    def test_list_components(self):
        """Test case for list_components

        """
        pass

    def test_update_component(self):
        """Test case for update_component

        """
        pass


if __name__ == '__main__':
    unittest.main()



import os
from kaistack.metadata.workflow_service import WorkflowService
from kaistack.metadata import context
from kaistack.metadata.tracking import *

def quick_tests():
    svc = WorkflowService("http://localhost:8888")
    r = svc.create_run("run-6pb2r.preprocess")
    os.environ[context._WORKFLOW_NAME_ENV] = "run-6pb2r"
    os.environ[context._POD_NAME_ENV] = "testlocal-123"
    os.environ[context._PIPELINE_RUN_ID_ENV] = '047e568d-2948-4153-8aa0-e7cc2482c150'
    os.environ[context._PIPELINE_TEMPLATE_NAME_ENV] = "preprocess"
    os.environ["KAISTACKSEVER_URL"] = "http://localhost:8888"
    log_metric("m1",3.0)
    log_metrics({"m2":2.0,"m1":1.0})
    log_param("p1","val1")
    log_params({"p2":"val2", "p3":"val3"})
    log_artifact_meta(artifact_name='preprocess-output_path', artifact_type='DATASET', properties={'b':'1'})
    #svc.log_artifact_meta(meta)
if __name__=="__main__":
    quick_tests()


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipelinecomponentapis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pipelinecomponentapis.proto',
  package='codegen',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x1bpipelinecomponentapis.proto\x12\x07\x63odegen\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x93\x01\n\x11PipelineComponent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0f\n\x07\x63reator\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\x12\x10\n\x08helpLink\x18\x07 \x01(\t\x12\x0c\n\x04spec\x18\x08 \x01(\t\"!\n\x13GetComponentRequest\x12\n\n\x02id\x18\x01 \x01(\t\"T\n\x14GetComponentResponse\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"#\n\x15ListComponentsRequest\x12\n\n\x02id\x18\x01 \x01(\t\"W\n\x16ListComponentsResponse\x12.\n\ncomponents\x18\x01 \x03(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"G\n\x16\x43reateComponentRequest\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\"W\n\x17\x43reateComponentResponse\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"G\n\x16UpdateComponentRequest\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\"W\n\x17UpdateComponentResponse\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"*\n\x1cListComponentVersionsRequest\x12\n\n\x02id\x18\x01 \x01(\t\"^\n\x1dListComponentVersionsResponse\x12.\n\ncomponents\x18\x01 \x03(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"$\n\x16\x44\x65leteComponentRequest\x12\n\n\x02id\x18\x01 \x01(\t\"9\n\x17\x44\x65leteComponentResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t2\x93\x06\n\x18PipelineComponentService\x12j\n\x0eListComponents\x12\x16.google.protobuf.Empty\x1a\x1f.codegen.ListComponentsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/pipeline/components\x12r\n\rGetComponents\x12\x1c.codegen.GetComponentRequest\x1a\x1d.codegen.GetComponentResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/pipeline/components/{id}\x12\x80\x01\n\x0f\x43reateComponent\x12\x1f.codegen.CreateComponentRequest\x1a .codegen.CreateComponentResponse\"*\x82\xd3\xe4\x93\x02$\"\x17/v1/pipeline/components:\tcomponent\x12\x80\x01\n\x0fUpdateComponent\x12\x1f.codegen.UpdateComponentRequest\x1a .codegen.UpdateComponentResponse\"*\x82\xd3\xe4\x93\x02$\x1a\x17/v1/pipeline/components:\tcomponent\x12\x94\x01\n\x15ListComponentVersions\x12%.codegen.ListComponentVersionsRequest\x1a&.codegen.ListComponentVersionsResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/pipeline/components/verions/{id}\x12z\n\x0f\x44\x65leteComponent\x12\x1f.codegen.DeleteComponentRequest\x1a .codegen.DeleteComponentResponse\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/v1/pipeline/components/{id}b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_PIPELINECOMPONENT = _descriptor.Descriptor(
  name='PipelineComponent',
  full_name='codegen.PipelineComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.PipelineComponent.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='codegen.PipelineComponent.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='codegen.PipelineComponent.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='codegen.PipelineComponent.image', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='codegen.PipelineComponent.creator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='codegen.PipelineComponent.version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='helpLink', full_name='codegen.PipelineComponent.helpLink', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='codegen.PipelineComponent.spec', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=280,
)


_GETCOMPONENTREQUEST = _descriptor.Descriptor(
  name='GetComponentRequest',
  full_name='codegen.GetComponentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.GetComponentRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=315,
)


_GETCOMPONENTRESPONSE = _descriptor.Descriptor(
  name='GetComponentResponse',
  full_name='codegen.GetComponentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.GetComponentResponse.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.GetComponentResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=401,
)


_LISTCOMPONENTSREQUEST = _descriptor.Descriptor(
  name='ListComponentsRequest',
  full_name='codegen.ListComponentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.ListComponentsRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=438,
)


_LISTCOMPONENTSRESPONSE = _descriptor.Descriptor(
  name='ListComponentsResponse',
  full_name='codegen.ListComponentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='components', full_name='codegen.ListComponentsResponse.components', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.ListComponentsResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=527,
)


_CREATECOMPONENTREQUEST = _descriptor.Descriptor(
  name='CreateComponentRequest',
  full_name='codegen.CreateComponentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.CreateComponentRequest.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=600,
)


_CREATECOMPONENTRESPONSE = _descriptor.Descriptor(
  name='CreateComponentResponse',
  full_name='codegen.CreateComponentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.CreateComponentResponse.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.CreateComponentResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=689,
)


_UPDATECOMPONENTREQUEST = _descriptor.Descriptor(
  name='UpdateComponentRequest',
  full_name='codegen.UpdateComponentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.UpdateComponentRequest.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=762,
)


_UPDATECOMPONENTRESPONSE = _descriptor.Descriptor(
  name='UpdateComponentResponse',
  full_name='codegen.UpdateComponentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.UpdateComponentResponse.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.UpdateComponentResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=764,
  serialized_end=851,
)


_LISTCOMPONENTVERSIONSREQUEST = _descriptor.Descriptor(
  name='ListComponentVersionsRequest',
  full_name='codegen.ListComponentVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.ListComponentVersionsRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=895,
)


_LISTCOMPONENTVERSIONSRESPONSE = _descriptor.Descriptor(
  name='ListComponentVersionsResponse',
  full_name='codegen.ListComponentVersionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='components', full_name='codegen.ListComponentVersionsResponse.components', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.ListComponentVersionsResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=897,
  serialized_end=991,
)


_DELETECOMPONENTREQUEST = _descriptor.Descriptor(
  name='DeleteComponentRequest',
  full_name='codegen.DeleteComponentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.DeleteComponentRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1029,
)


_DELETECOMPONENTRESPONSE = _descriptor.Descriptor(
  name='DeleteComponentResponse',
  full_name='codegen.DeleteComponentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='codegen.DeleteComponentResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.DeleteComponentResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1088,
)

_GETCOMPONENTRESPONSE.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_LISTCOMPONENTSRESPONSE.fields_by_name['components'].message_type = _PIPELINECOMPONENT
_CREATECOMPONENTREQUEST.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_CREATECOMPONENTRESPONSE.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_UPDATECOMPONENTREQUEST.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_UPDATECOMPONENTRESPONSE.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_LISTCOMPONENTVERSIONSRESPONSE.fields_by_name['components'].message_type = _PIPELINECOMPONENT
DESCRIPTOR.message_types_by_name['PipelineComponent'] = _PIPELINECOMPONENT
DESCRIPTOR.message_types_by_name['GetComponentRequest'] = _GETCOMPONENTREQUEST
DESCRIPTOR.message_types_by_name['GetComponentResponse'] = _GETCOMPONENTRESPONSE
DESCRIPTOR.message_types_by_name['ListComponentsRequest'] = _LISTCOMPONENTSREQUEST
DESCRIPTOR.message_types_by_name['ListComponentsResponse'] = _LISTCOMPONENTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateComponentRequest'] = _CREATECOMPONENTREQUEST
DESCRIPTOR.message_types_by_name['CreateComponentResponse'] = _CREATECOMPONENTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateComponentRequest'] = _UPDATECOMPONENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateComponentResponse'] = _UPDATECOMPONENTRESPONSE
DESCRIPTOR.message_types_by_name['ListComponentVersionsRequest'] = _LISTCOMPONENTVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListComponentVersionsResponse'] = _LISTCOMPONENTVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteComponentRequest'] = _DELETECOMPONENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteComponentResponse'] = _DELETECOMPONENTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PipelineComponent = _reflection.GeneratedProtocolMessageType('PipelineComponent', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINECOMPONENT,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.PipelineComponent)
  })
_sym_db.RegisterMessage(PipelineComponent)

GetComponentRequest = _reflection.GeneratedProtocolMessageType('GetComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPONENTREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.GetComponentRequest)
  })
_sym_db.RegisterMessage(GetComponentRequest)

GetComponentResponse = _reflection.GeneratedProtocolMessageType('GetComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPONENTRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.GetComponentResponse)
  })
_sym_db.RegisterMessage(GetComponentResponse)

ListComponentsRequest = _reflection.GeneratedProtocolMessageType('ListComponentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPONENTSREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.ListComponentsRequest)
  })
_sym_db.RegisterMessage(ListComponentsRequest)

ListComponentsResponse = _reflection.GeneratedProtocolMessageType('ListComponentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPONENTSRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.ListComponentsResponse)
  })
_sym_db.RegisterMessage(ListComponentsResponse)

CreateComponentRequest = _reflection.GeneratedProtocolMessageType('CreateComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMPONENTREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.CreateComponentRequest)
  })
_sym_db.RegisterMessage(CreateComponentRequest)

CreateComponentResponse = _reflection.GeneratedProtocolMessageType('CreateComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMPONENTRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.CreateComponentResponse)
  })
_sym_db.RegisterMessage(CreateComponentResponse)

UpdateComponentRequest = _reflection.GeneratedProtocolMessageType('UpdateComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMPONENTREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.UpdateComponentRequest)
  })
_sym_db.RegisterMessage(UpdateComponentRequest)

UpdateComponentResponse = _reflection.GeneratedProtocolMessageType('UpdateComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMPONENTRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.UpdateComponentResponse)
  })
_sym_db.RegisterMessage(UpdateComponentResponse)

ListComponentVersionsRequest = _reflection.GeneratedProtocolMessageType('ListComponentVersionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPONENTVERSIONSREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.ListComponentVersionsRequest)
  })
_sym_db.RegisterMessage(ListComponentVersionsRequest)

ListComponentVersionsResponse = _reflection.GeneratedProtocolMessageType('ListComponentVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPONENTVERSIONSRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.ListComponentVersionsResponse)
  })
_sym_db.RegisterMessage(ListComponentVersionsResponse)

DeleteComponentRequest = _reflection.GeneratedProtocolMessageType('DeleteComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECOMPONENTREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.DeleteComponentRequest)
  })
_sym_db.RegisterMessage(DeleteComponentRequest)

DeleteComponentResponse = _reflection.GeneratedProtocolMessageType('DeleteComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECOMPONENTRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.DeleteComponentResponse)
  })
_sym_db.RegisterMessage(DeleteComponentResponse)



_PIPELINECOMPONENTSERVICE = _descriptor.ServiceDescriptor(
  name='PipelineComponentService',
  full_name='codegen.PipelineComponentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1091,
  serialized_end=1878,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListComponents',
    full_name='codegen.PipelineComponentService.ListComponents',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTCOMPONENTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/v1/pipeline/components',
  ),
  _descriptor.MethodDescriptor(
    name='GetComponents',
    full_name='codegen.PipelineComponentService.GetComponents',
    index=1,
    containing_service=None,
    input_type=_GETCOMPONENTREQUEST,
    output_type=_GETCOMPONENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/v1/pipeline/components/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='CreateComponent',
    full_name='codegen.PipelineComponentService.CreateComponent',
    index=2,
    containing_service=None,
    input_type=_CREATECOMPONENTREQUEST,
    output_type=_CREATECOMPONENTRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\027/v1/pipeline/components:\tcomponent',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateComponent',
    full_name='codegen.PipelineComponentService.UpdateComponent',
    index=3,
    containing_service=None,
    input_type=_UPDATECOMPONENTREQUEST,
    output_type=_UPDATECOMPONENTRESPONSE,
    serialized_options=b'\202\323\344\223\002$\032\027/v1/pipeline/components:\tcomponent',
  ),
  _descriptor.MethodDescriptor(
    name='ListComponentVersions',
    full_name='codegen.PipelineComponentService.ListComponentVersions',
    index=4,
    containing_service=None,
    input_type=_LISTCOMPONENTVERSIONSREQUEST,
    output_type=_LISTCOMPONENTVERSIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/v1/pipeline/components/verions/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteComponent',
    full_name='codegen.PipelineComponentService.DeleteComponent',
    index=5,
    containing_service=None,
    input_type=_DELETECOMPONENTREQUEST,
    output_type=_DELETECOMPONENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\036*\034/v1/pipeline/components/{id}',
  ),
])
_sym_db.RegisterServiceDescriptor(_PIPELINECOMPONENTSERVICE)

DESCRIPTOR.services_by_name['PipelineComponentService'] = _PIPELINECOMPONENTSERVICE

# @@protoc_insertion_point(module_scope)
